package authentication;

import java.security.Principal;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletRequestWrapper;
import javax.servlet.http.HttpSession;

/**
 * "Obal" pro HTTP poadavek. Obal HTTP poadavek tak, aby metody <code>getRemoteUser</code>, 
 * <code>getUserPrincipal</code> a <code>isUserInRole</code> pracovaly s informacemi uloenmi v session.
 */
public final class MyHttpRequest extends HttpServletRequestWrapper 
{
/** 
 * Vytvo instanci
 */
public MyHttpRequest(HttpServletRequest request) 
{
	super(request);
}
/**
 * Metoda vrt pihlaovac jmno uivatele, kter vyslal HTTP poadavek. Pracuje se session, s atributem 
 * jeho nzev je v <code>Constants.USER</code>.
 * @return java.lang.String je pihlaovac jmno uivatele.
 */
public String getRemoteUser() 
{
	HttpSession session = getSession(false);

	if (session != null) 
	{
		MyPrincipal principal = (MyPrincipal) session.getAttribute(Constants.USER);   
		if (principal != null) 
		{
			return principal.getName();
		}
	}
	return null;
}
/**
 * Metoda vrt principal s informacemi o uivateli, kter vyslal HTTP poadavek. Pracuje se session, s atributem 
 * jeho nzev je v <code>Constants.USER</code>.
 * @return java.lang.String je principal s informacemi o uivateli.
 */	
public Principal getUserPrincipal() 
{
	HttpSession session = getSession(false);
	if (session != null) 
	{
		MyPrincipal principal = (MyPrincipal) session.getAttribute(Constants.USER);   
		return principal;
	}
	return null;
}
/**
 * Metoda zjist, zda je uivatel asociovn se zadanou rol.
 * @return boolean je <code>true</code>, jestlie uivatel je asociovn s danou rol, jinak <code>false</code>.
 */
public boolean isUserInRole(String role) 
{
	MyPrincipal principal = (MyPrincipal)getUserPrincipal();
	if (principal != null)
	{
		return principal.isUserInRole(role);
	}  
	return false;
}
/**
 * Metoda vrt zpsob autentifikace.
 * @return java.lang.String je zpsob autentifikace.
 */
public java.lang.String getAuthType()
{
	HttpSession session = getSession(false);

	if (session != null) 
	{
		return (String) session.getAttribute(Constants.AUTHMETHOD);   
	}
	return null;

}


}
